@@ -100,9 +100,9 @@ estimateDataTemporalMap <- function(data = NULL, dateColumnName = NULL, period =
     validClasses <- c('numeric', 'integer', 'character', 'factor', 'Date')
     if( any(!sapply(data, class) %in% validClasses) )
         stop(paste("The classes of input columns must be one of the following:",paste(validClasses,collapse = ', ')))
-    if( !is.null(startDate) && class(startDate) != "Date")
+    if( !is.null(startDate) && inherits(startDate, "Date"))
         stop("The specified startDate must be of class Date")
-    if( !is.null(endDate) && class(endDate) != "Date")
+    if( !is.null(endDate) && inherits(endDate, "Date"))
         stop("The specified endDate must be of class Date")
     if ( any(!sapply(supports,class) %in% c('numeric', 'integer', 'character', 'factor')))
         stop("All the elements provided in the supports parameter must be of class data.frame")
